@@ -10,15 +10,13 @@ use vars qw(@ISA @EXPORT @EXPORT_OK);
 use Exporter 'import';
 
 # Exporting the implemented subroutine.
-# our @EXPORT = qw(
-#     sign
-# );
+our @EXPORT = qw();
 
 # Base class of this (tron_addr) module.
 our @ISA = qw(Exporter);
 
 # Set the package version. 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 1;
 
@@ -35,6 +33,7 @@ CryptoTron - Perl extension for use with the crypto coin Tron blockchain
   use CryptoTron::AddressConvert
   use CryptoTron::AddressCheck
   use CryptoTron::AddrTools
+  use CryptoTron::CreateAccount
 
 =head1 DESCRIPTION
 
@@ -54,6 +53,8 @@ CryptoTron modules:
 
   CryptoTron::ClaimReward
 
+  CryptoTron::CreateAccount
+
 CPAN modules:
 
   URI
